#!/bin/bash

# This script is used to monitor ds1490f USB-1wire adapter, owfs service and start them if needed
# Argo Ellisson 2014, BashPi.org, usage licence: GNU General Public License (GPL) Version 3
# version 1.0

# First check is some other monitoring process already running and exit if it is
pidof -x -o $$ wire_monitor.sh >& /dev/null && exit 0

# functions

# gets user homedir
get_homedir() {
       getent passwd ${1} |cut -d':' -f6
}

# gets number of owfs mountpoints 
owfs_mounts(){
	mount | grep "OWFS on ${1}" | grep -v grep |wc -l
}

# wire user
USER="wire"
USERHOME=`get_homedir ${USER}`
MOUNT="/wire"

# wait some time during startup
sleep 60

FUSELOADED=`lsmod | grep fuse | wc -l`
OWFS=`owfs_mounts ${MOUNT}`

# check responsiveness of /1wire, not contents
ls ${MOUNT} > /dev/null 2>&1
OWFSRESP=$?

# if should work but unresponsive - unload all
if [ $OWFSRESP -ne 0 ];then

        echo "${MOUNT} is not responsive, unmounting ${MOUNT} and unloading fuse"
	sudo umount -f ${MOUNT}  > /dev/null 2>&1
	sleep 2
        pkill -9 owfs
	sudo rmmod -f fuse  > /dev/null 2>&1
	FUSELOADED=0
	OWFS=0
	sleep 5

fi

if [ $FUSELOADED -eq 0 ];then

	#load fuse module
        echo "loading fuse"
	sudo modprobe fuse
	sleep 5

fi

if [ $OWFS -eq 0 ];then

	# with increased timeouts
	/usr/bin/owfs --allow_other --timeout_volatile=30 --timeout_presence=300 -u -m ${MOUNT}

	# now everything should either still run or was just started up
	# check again and exit with appropriate code

	OWFS=`owfs_mounts ${MOUNT}`

	if [ $OWFS -eq 0 ];then

        	echo "OWFS is not mounted"
        	exit 1
	fi

fi

# already ok
echo "OWFS mounted and ok"
exit 0
