files/
functions.sh  fuse.conf  owfs.conf  wire_crontab  wire_homedir  wire_sudoers



root@raspberrypi:/mnt/wire# cat configure.sh 
#!/bin/bash

# this script tries to configure thing related to 1-wire
# Argo Ellisson 2014
# version 1.0

if [ "$(id -u)" -ne "0" ] ; then
    echo "This script must be executed with root privileges."
    exit 1
fi

# change curent directory to script location
cd $(dirname $0)

# include functions
. ../functions.sh

# wire user homedir backup location
WIREHOMEBACKUP="../../wire"
# wire username
WIREUSER="wire"
# wire udev rules filename
WIREUDEV="11-1wire.rules"

usage() {
    echo THIS may screw up some existing config in your system, please check the script if you care
    echo to avoid accidental running please use following to apply configuration:
    echo usage: configure.sh configure
    echo must be run as root user either directly or using sudo
    cd - > /dev/null
    exit 1
}

case "$1" in
        configure)  echo "installing packages and configuring if needed"

        # seting up mountpoint
        [ -d /1wire ] || mkdir /1wire
        chown ${WIREUSER}:${WIREUSER} /1wire 

        # this will also install other required packages
        echo installing packages if needed
        try_install owfs
        try_install owfs-common

        # turn off services what are not used in this project
        echo switching off services owftpd owhttpd owserver, because we dont need them in this project
        update-rc.d -f owftpd disable
        update-rc.d -f owhttpd disable
        update-rc.d -f owserver disable
        service owftpd stop
        service owhttpd stop
        service owserver stop
        # 1wire conf
        echo backing up and replacing /etc/owfs.conf
        [[ -f /etc/owfs.conf ]] && cp /etc/owfs.conf /etc/owfs.conf.old
        cp ./files/owfs.conf /etc/

        echo seting up user
        add_systemuser ${WIREUSER}
        WIREHOME=`get_homedir ${WIREUSER}`
        echo syncing ${WIREUSER} homedir contents
        rsync -av ${WIREHOMEBACKUP}/* ${WIREHOME}
        chown ${WIREUSER}:${WIREUSER} ${WIREHOME}/*
        usermod -a -G fuse ${WIREUSER}

        # importing crontab
        crontab -u ${WIREUSER} ./files/crontab

        # copy fuse conf and sudo rules
        cp ./files/wiresudo /etc/sudoers.d/
        cp ./files/fuse.conf /etc/

        # udev rules
        echo seting up udev rules for Dallas Semiconductor DS1490F
        echo "# rule for DS1490F. runs monitoring script" > /etc/udev/rules.d/${WIREUDEV}
        echo "Bus 001 Device 008: ID 04fa:2490 Dallas Semiconductor DS1490F 2-in-1 Fob, 1-Wire adapter" >> /etc/udev/rules.d/${WIREUDEV}
        echo "ATTRS{idVendor}==\"04fa\", ATTRS{idProduct}==\"2490\", OWNER=\"${WIREUSER}\", GROUP=\"${WIREUSER}\", MODE=\"0660\", SYMLINK+=\"ds1490f\", RUN+=\"/bin/su - ${WIREUSER} -c ${WIREHOME}/1wiremon.sh &\"" >> /etc/udev/rules.d/${WIREUDEV}
        udevadm control --reload-rules

        echo configured!

        ;;
        *) echo "incorrect usage"
        usage
        ;;
esac

cd - > /dev/null

exit 0

